@@ -9,7 +9,7 @@ import re
 
 from config import java
 from util import newTempfile, runcmd
-from elementtree.ElementTree import parse, tostring        
+from elementtree.ElementTree import parse, tostring, SubElement        
 from htmlentitydefs import name2codepoint
 from BeautifulSoup import BeautifulSoup
 
@@ -121,12 +121,24 @@ class HTML2FOConverter(object):
 
             if get('text-transform'):
                 del node.attrib['text-transform']
+
+            value = get('white-space')
+            if value == 'pre':
+                del node.attrib['white-space']
+                node.text = '\n' + node.text.lstrip()
+                for k,v in  {'white-space-treatment' : 'preserve',
+                             'white-space-collapse' : 'false',
+                             'wrap-option' : 'no-wrap',
+                             'linefeed-treatment' : 'preserve' }.items():
+                    node.attrib[k] = v
                 
         fo_text = tostring(E.getroot())
         fo_text = fo_text.replace('<ns0:block ' , '<ns0:block margin-top="0" margin-bottom="0" ')  # avoid a linebreak through <li><p> (XFC)
-        fo_text = fo_text.replace('<ns0:block/>', '') # causes a crash with XINC    
+#        fo_text = fo_text.replace('<ns0:block/>', '') # causes a crash with XINC    
         fo_text = fo_text.replace('<ns0:block margin-top="0" margin-bottom="0" />', '') 
 
+
+        print fo_text
         open(fo_filename, 'wb').write(fo_text)
         return fo_filename
 
